#!/usr/bin/env bash

    #####################################################################
    ##                 __            __ _ ___________                  ##
    ##                 \ \          / /| |____   ____|                 ##
    ##                  \ \        / / | |    | |                      ##
    ##                   \ \  /\  / /  | |    | |                      ##
    ##                    \ \/  \/ /   | |    | |                      ##
    ##                     \  /\  /    | |    | |                      ##
    ##                      \/  \/     |_|    |_|                      ##
    ##                                                                 ##
    ##                        Wiimms ISO Tools                         ##
    ##                      https://wit.wiimm.de/                      ##
    ##                                                                 ##
    #####################################################################
    ##                                                                 ##
    ##   This file is part of the WIT project.                         ##
    ##   Visit https://wit.wiimm.de/ for project details and sources.  ##
    ##                                                                 ##
    ##   Copyright (c) 2009-2021 by Dirk Clemens <wiimm@wiimm.de>      ##
    ##                                                                 ##
    #####################################################################
    ##                                                                 ##
    ##   This file installs the distribution.                          ##
    ##                                                                 ##
    #####################################################################


#------------------------------------------------------------------------------
# sudo?

try_sudo=1
if [[ $1 = --no-sudo ]]
then
    try_sudo=0
    shift
else
    uid="$(id -u 2>/dev/null)" || try_sudo=0
    [[ $uid = 0 ]] && try_sudo=0
fi

if ((try_sudo))
then
    echo "*** need root privileges to install => try sudo ***"
    sudo "$0" --no-sudo "$@"
    exit $?
fi

#------------------------------------------------------------------------------
# settings

SYSTEM="x86_64"
SYSTEM2="x86_64"

BASE_PATH="/usr/local"
BIN_PATH="$BASE_PATH/bin"
SHARE_PATH="/usr/local/share/wit"

BIN_FILES="wit wwt wdf wfuse "
WDF_LINKS="wdf-cat wdf-dump"
SHARE_FILES="titles.txt titles-de.txt titles-es.txt titles-fr.txt titles-it.txt titles-ja.txt titles-ko.txt titles-nl.txt titles-pt.txt titles-ru.txt titles-zhcn.txt titles-zhtw.txt system-menu.txt magic.txt"

INST_FLAGS="-p"

#------------------------------------------------------------------------------
# make?

make=0
if [[ $1 = --make ]]
then
    # it's called from make
    make=1
    shift
fi

#------------------------------------------------------------------------------
echo "*** install binaries to $BIN_PATH"

for f in $BIN_FILES
do
    [[ -f bin/$f ]] || continue
    mkdir -p "$BIN_PATH"
    install $INST_FLAGS bin/$f "$BIN_PATH/$f"
done

[[ $SYSTEM = mac ]] && xattr -dr com.apple.quarantine "$BIN_PATH" || true

#------------------------------------------------------------------------------
echo "*** create wdf links"

for f in $WDF_LINKS
do
    [[ -f "$BIN_PATH/wdf"  ]] && ln -f "$BIN_PATH/wdf"  "$BIN_PATH/$f"
done

#------------------------------------------------------------------------------
echo "*** install share files to $SHARE_PATH"

for f in $SHARE_FILES
do
    mkdir -p "$SHARE_PATH"
    install $INST_FLAGS -m 644 share/$f "$SHARE_PATH/$f"
done

if [[ -f ./load-titles.sh ]]
then
    mkdir -p "$SHARE_PATH"
    install $INST_FLAGS -m 755 ./load-titles.sh "$SHARE_PATH/load-titles.sh"
fi

#------------------------------------------------------------------------------
# load titles

((make)) || ./load-titles.sh

#------------------------------------------------------------------------------

exit 0

